CityNameRepositoryImpl class
- Inheritance
-
- Object
- ICityNameRepository
- CityNameRepositoryImpl
Constructors
- CityNameRepositoryImpl({required ICityNameService iCityNameService, required ILocationServiceGeoLocatorProvider iLocationServiceGeoLocatorProvider})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iCityNameService → ICityNameService
-
final
- iLocationServiceGeoLocatorProvider → ILocationServiceGeoLocatorProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCityName(
LocationEntity locationEntity) → Future< Either< IFailure, String> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited